###########################################################
### Ch4 - Script 2 - MtFTa2_Medtr7g085020
###########################################################

###########################################################
### Theme
###########################################################
theme_set(my_theme())

###########################################################
### NF9778
###
### Tnt1 line         Q527, Q589
### Wild-type (R108)  Q536, Q597
###########################################################

# Flowering time graph
NF9778_flowering <- FTdata %>% 
  filter(sowing_number %in% c("Q527", "Q536", "Q589", "Q597")) %>% 
  mutate(mutant = fct_rev(mutant)) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(10, 8)]) +
  stat_ellipse(size = 1, alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 30)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 12)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position='none',#c(.15, .91),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2)) +
  facet_wrap(~conditions) +
  ggtitle("N9778")

###########################################################
### NF9421 gene expression
###
### NF9421            Q033
### Wild-type (R108)  Q042
###########################################################

labels <- c("Q033_plant_2" = "NF9421 \nplant #1",
            "Q033_plant_4" = "NF9421 \nplant #2",
            "Q042_plant_8" = 'Wild-type')

gene_expr %>% 
  filter(date == '05/09/16') %>% 
  rt_summary() %>% 
  rt_test() %>%

ggplot(aes(fct_reorder(sample, mean_expr, .desc = T), mean_expr, fill = genotype)) +
  geom_col() +
  geom_errorbar(aes(ymin = mean_expr - se, ymax =  mean_expr + se), width = 0.2) +
  scale_y_continuous(expand = c(0,0), limits = c(0,1)) +
  scale_x_discrete(labels = labels) +
  theme(axis.title.x = element_blank(), 
        legend.position= "none") +
  scale_fill_manual(values = g_colours[c(3, 8)]) +
  labs(y = expression("Expression relative to"~italic("PP2A")))

# ggsave("NF9421_expr.pdf", width = 142, height = 140, units = 'mm')

gene_expr %>% 
  filter(date == '05/09/16') %>%
  rt_calc() %>% 
  left_join(enframe(labels) %>% 
              mutate(value = str_replace_all(value, '\n', "")) %>% 
              rename(sample = name)
  ) %>% 
  ungroup() %>% 
  mutate(sample = paste0(value, " (", sample, ")")) %>% 
  select(-value) 

###########################################################
### NF19514 gene expression
###
### NF19514           Q272
### Wild-type (R108)  Q279
###########################################################

labels <- c("Q272_plant_1" = "NF19514 \nplant #1",
            "Q272_plant_16" = "NF19514 \nplant #2",
            "Q279_plant_15" = "Wild-type")

gene_expr %>% 
  filter(date == '06/12/16') %>% 
  rt_summary() %>% 
  rt_test() %>%

  ggplot(aes(fct_relevel(sample, "Q279_plant_15"), mean_expr, fill = genotype)) +
  geom_col() +
  geom_errorbar(aes(ymin = mean_expr - se, ymax =  mean_expr + se), width = 0.2) +
  scale_y_continuous(expand = c(0,0), limits = c(0,1)) +
  scale_x_discrete(labels = labels) +
  theme(axis.title.x = element_blank(), 
        legend.position= "none") +
  scale_fill_manual(values = g_colours[c(3, 8)]) +
  labs(y = expression("Expression relative to"~italic("PP2A")))


# ggsave("NF19514_expr.pdf", width = 142, height = 140, units = 'mm')

gene_expr %>% 
  filter(date == '06/12/16') %>% 
  rt_calc() %>% 
  left_join(enframe(labels) %>% 
              mutate(value = str_replace_all(value, '\n', "")) %>% 
              rename(sample = name)
            ) %>% 
  ungroup() %>% 
  mutate(sample = paste0(value, " (", sample, ")")) %>% 
  select(-value) 

# NF9421 significance
gene_expr %>% 
  filter(date == '05/09/16') %>% 
  rt_summary() %>% 
  rt_test() %>% 
  mutate(data = map(data, ~ select(.x, bio_replicate, comp_exp))) %>% 
  unnest(data) %$% 
  aov(comp_exp ~ sample) %>% 
  # summary() %>% 
  TukeyHSD()


# NF19514 significance
gene_expr %>% 
  filter(date == '06/12/16') %>% 
  rt_summary() %>% 
  rt_test() %>% 
  mutate(data = map(data, ~ select(.x, bio_replicate, comp_exp))) %>% 
  unnest(data) %$% 
  aov(comp_exp ~ sample) %>% 
  # summary() 
  TukeyHSD()

###########################################################
### NF9421 flowering time
###
###         NF9421             Wild-type (R108)
### VLD     Q033 (Segregating) Q042
### SD      Q425               Q429
### VSD     Q275               Q281
###
### Segregating Population
###         NF9421             Wild-type (R108)
### VSD     Q477 (Segregating) Q479
###########################################################

# Flowering time
NF9421_flowering <- FTdata %>% 
  filter(sowing_number %in% c("Q033", "Q042", "Q425", "Q429", "Q275", "Q281"),
         !(sowing_number %in% c("Q033", "Q042") & conditions == 'VSD')) %>%
  mutate(conditions = fct_relevel(conditions, "VLD", "VSD"),
         mutant = fct_relevel(mutant, "Homozygote", "Wild-type segregant")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.8) +
  scale_colour_manual(values = g_colours[c(3, 10, 8)]) +
  stat_ellipse(size = 1, alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 90), breaks = seq(0, 90, 10)[c(T,F)]) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 15)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="none",#c(.12, .86),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2)) +
  facet_wrap(~conditions) +
  ggtitle('NF9421')

# Segregating population
FTdata %>% 
  filter(sowing_number %in% c("Q477", "Q479")) %>% 
  mutate(mutant = if_else(mutant == "Wild-type", "Wild-type (R108)", mutant),
         mutant = fct_relevel(mutant, "Homozygote", "Heterozygote", "Wild-type segregant")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.8) +
  scale_colour_manual(values = g_colours[c(3, 9, 10, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 90), breaks = seq(0, 90, 10)[c(T,F)]) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 20)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.2, .9),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2)) 

# ggsave("Ch4_NF9421_segregation_flowering.png", width = 179, height = 151, units = "mm")

linkage_tally <- FTdata %>% 
  filter(sowing_number %in% c("Q477"))  %>% 
  mutate(mutant = fct_relevel(mutant, "Homozygote", "Heterozygote", "Wild-type segregant")) %>% 
  group_by(mutant) %>% 
  tally() %>%
  mutate(expected = c(0.25, 0.5, 0.25)) %$%
  chisq.test(n, p = expected) %>% 
  broom::tidy()

###########################################################
### NF19514 flowering time
###
###         NF19514            Wild-type (R108)
### VLD     Q272 (Segregating) Q279
### VSD     Q489 and Q490      Q493
###########################################################

NF19514_flowering <- FTdata %>%
  filter(sowing_number %in% c("Q272", "Q279", "Q489", "Q490", "Q493")) %>%
  mutate(mutant = if_else(mutant == "Wild-type", "Wild-type (R108)", mutant),
         mutant = fct_relevel(mutant, "Homozygote", "Heterozygote", "Wild-type segregant")) %>%
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.8) +
  scale_colour_manual(values = g_colours[c(3, 9, 10, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 90), breaks = seq(0, 80, 10)[c(T,F)]) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 20)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.13, .83),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2)) +
  facet_wrap(~conditions) +
  ggtitle("NF19514")

ggarrange(NF9421_flowering, 
          ggarrange(NF19514_flowering, NF9778_flowering,
                    ncol = 2, widths = c(2, 1), 
                    labels = c("B", "C"), font.label = list(size = 24)),
          nrow=2, labels = c("A", ""),
          font.label = list(size = 24))

# ggsave('Ch4_FTa2_Flowering.png', width = 393, height = 212, units = "mm")
