###########################################################
### Ch4 - Script 4 - MtFTb2_Medtr7g006690
###########################################################

###########################################################
### Theme
###########################################################
theme_set(my_theme())

###########################################################
### NF17918
###
### Tnt1 line         Q037
### Wild-type (R108)  Q042
###########################################################

# Flowering time graph
NF17918_flowering <- FTdata %>% 
  filter(sowing_number %in% c("Q037", "Q042"),
         !(sowing_number == "Q042" & conditions == 'VSD')) %>% 
  mutate(mutant = if_else(mutant == "Wild-type", "Wild-type (R108)", mutant),
         mutant = factor(mutant, levels = c("Homozygote", "Wild-type segregant", "Wild-type (R108)"))) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 10, 8)], drop = FALSE) +
  stat_ellipse(size = 1, alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 30)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 10)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="none",#c(.3, .90),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        axis.title.x = element_text(vjust = -2)) +
  ggtitle("NF17918")

###########################################################
### NF20803 flowering time
###
###           NF20803   Wild-type (R108)
### Screening Q036      Q042
### VLD       Q232      Q235  
### LD        Q232      Q233
###
### LD (rep.) Q452      Q454
###
### Condensed phenotype
### VLD       Q381                  Q382 (Hets & WT segs 
### LD        Q372      Q373              of NF1634 
###                                       backcross)
###########################################################

# Flowering time of NF20803 screening
NF20803_screening <- FTdata %>% 
  filter(sowing_number %in% c("Q036", "Q042"),
         !(sowing_number == "Q042" & conditions == 'VSD')) %>%
  mutate(mutant = if_else(mutant == "Wild-type", "Wild-type (R108)", mutant),
         mutant = fct_relevel(mutant, "Homozygote", "Heterozygote", "Wild-type segregant")) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 9, 10, 8)]) +
  stat_ellipse(size = 1, alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 30)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 10)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.2, .9),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        axis.title.x = element_text(vjust = -2)) +
  ggtitle('NF20803')

# Flowering time
NF20803_flowering <- FTdata %>% 
  filter(sowing_number %in% c("Q232", "Q233", "Q235")) %>%
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  stat_ellipse(size = 1, alpha = 0.6) +
  facet_wrap(~ fct_rev(conditions)) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 65)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 25)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position="none",#c(.08, .9),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2)) +
  ggtitle('NF20803')

ggarrange(ggarrange(NF17918_flowering, NF20803_screening, 
                    align = "h", labels = c("A", "B"),
                    font.label = list(size = 24)),
          NF20803_flowering, 
          nrow = 2, labels = c(" ", "C"),
          font.label = list(size = 24))

# ggsave("Ch4_NF20803_flowering.png", width = 374, height = 244, units = "mm")

# LD replication
FTdata %>% 
  filter(sowing_number %in% c("Q452", "Q454")) %>% 
  mutate(mutant = if_else(mutant == "Wild-type", "Wild-type (R108)", mutant)) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  stat_ellipse(size = 1, alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 80)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 22)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.12, .86),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2))

# ggsave("Ch4_NF20803_LD_replication_flowering.png", width = 179, height = 151, units = "mm")

# Flowering time of small plants
int_flr <- FTdata %>% 
  filter(sowing_number %in% c("Q372", "Q373", "Q381", "Q382")) %>% 
  mutate(mutant = if_else(mutant == "Wild-type", "Wild-type (R108)", mutant),
         mutant = case_when(sowing_number == "Q382" ~ "Wild-type (R108)",
                            mutant == "Homozygote" ~ "Homozygote (compact)",
                            TRUE ~ mutant)) %>% 
  ggplot(aes(days_to_flower, node_num, colour = mutant)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  stat_ellipse(size = 1, alpha = 0.6) +
  facet_wrap(~ fct_rev(conditions)) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 65)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 22)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.08, .8),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2))

###########################################################
### NF20803 Condensed phenotype
###
### VLD       Q381                  Q382 (Hets & WT segs 
### LD        Q372      Q373              of NF1634 
###                                       backcross)
###########################################################

# Height
int_height <- internode %>% 
  filter(sowing_number %in% c("Q372", "Q373", "Q381", "Q382")) %>% 
  mutate(genotype = if_else(genotype == 'NF20803', 'NF20803 \n(compact)', 'Wild \ntype'),
         conditions = paste0(conditions, " - ", age, " days")) %>% 
  
  ggplot(aes(genotype, plant_height)) + 
  geom_boxplot(size=0.75) + 
  geom_jitter(size=2, width = 0.1, aes(colour = genotype), alpha = 0.7) +
  facet_wrap(~ fct_rev(conditions)) +
  geom_signif(comparisons = list(c('NF20803 \n(compact)', 'Wild \ntype')),
              test = 't.test', y_position = 16) +
  scale_colour_manual(values = g_colours[c(3, 8)], 
                      labels = c('NF20803', 'Wild-type')) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 20)) +
  theme(legend.position = "none",
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = 0, face="bold", size=14),
        axis.title = element_text(size=20),
        axis.title.x = element_blank()) +
  labs(y = "Plant Height (cm)")

# Width
int_width <- internode %>% 
  filter(sowing_number %in% c("Q372", "Q373", "Q381", "Q382")) %>% 
  mutate(genotype = if_else(genotype == 'NF20803', 'NF20803 \n(compact)', 'Wild \ntype'),
         conditions = paste0(conditions, " - ", age, " days")) %>% 
  
  ggplot(aes(genotype, secondary_axis_length)) + 
  geom_boxplot(size=0.75, outlier.alpha = 0) + 
  geom_jitter(size=2, width = 0.1, aes(colour = genotype), alpha = 0.7) +
  facet_wrap(~ fct_rev(conditions)) +
  geom_signif(comparisons = list(c('NF20803 \n(compact)', 'Wild \ntype')),
              test = 't.test', y_position = 30) +
  scale_colour_manual(values = g_colours[c(3, 8)], 
                      labels = c('NF20803', 'Wild-type')) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 35)) +
  theme(legend.position = "none",
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = 0, face="bold", size=14),
        axis.title = element_text(size=20),
        axis.title.x = element_blank()) +
  labs(y = "Secondary axis length (cm)")

# Node number
internode_long <- internode %>% 
  filter(sowing_number %in% c("Q372", "Q373", "Q381", "Q382")) %>% 
  mutate(genotype = if_else(genotype == 'NF20803', 'NF20803 \n(compact)', 'Wild \ntype')) %>%  
  mutate(plant_id = factor(paste0(sowing_number, "-", plant_number)),
         conditions = paste0(conditions, " - ", age, " days")) %>% 
  select(plant_id, conditions, genotype, matches('N[0-9]')) %>% 
  gather(node, value, -plant_id, -conditions, -genotype) %>% 
  filter(!is.na(value)) 

int_node_num <- internode_long %>% 
  group_by(conditions, genotype, plant_id) %>% 
  tally() %>% 
  ggplot(aes(genotype, n)) + 
  geom_boxplot(size=0.75, outlier.alpha = 0) + 
  geom_jitter(size=2, width = 0.1, aes(colour = genotype), alpha = 0.7) +
  facet_wrap(~ fct_rev(conditions)) +
  geom_signif(comparisons = list(c('NF20803 \n(compact)', 'Wild \ntype')),
              test = 't.test', y_position = 21) +
  scale_colour_manual(values = g_colours[c(3, 8)], 
                      labels = c('NF20803', 'Wild-type')) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 25)) +
  theme(legend.position = "none",
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = 0, face="bold", size=14),
        axis.title = element_text(size=20),
        axis.title.x = element_blank()) +
  labs(y = "Node number")

# Internode distribution
int_dist <- internode_long %>% 
  mutate(node = str_remove(string = node, "N") %>% 
           as.numeric()) %>% 
  arrange(plant_id, node) %>% 
  mutate(internode = if_else(node == 0, 0, value - lag(value))) %>% 
  group_by(conditions, genotype, node) %>% 
  mutate(mean_internodes = mean(internode),
         node_num = n(),
         node_sd = sd(internode),
         moe = qt(0.95, node_num - 1) * (node_sd/sqrt(node_num))
         ) %>%
  select(conditions, genotype, node, mean_internodes, moe) %>%
  distinct() %>% 
  
  ggplot(aes(mean_internodes, node,  group = genotype, colour = genotype)) +
  geom_path() +
  geom_point() +
  geom_errorbarh(aes(xmin = mean_internodes - moe, xmax = mean_internodes + moe), 
                 height = 0.5) +
  facet_wrap(~ fct_rev(conditions), scales = "free_x") +
  scale_colour_manual(values = g_colours[c(3, 8)], 
                      labels = c('NF20803 (compact)', 'Wild-type (R108)')) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 20)) +
  theme(legend.position = c(0.15, 0.9),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = 0, face="bold", size=14),
        axis.title = element_text(size=20)) +
  labs(x = "Internode length (cm)",y = "Internode")